@@ -1,8 +1,8 @@
  /*
  * Project       : ipv6calc
  * File          : dbipv6_assignment.h
- * Version       : $Id: dbipv6addr_assignment.h,v 1.26 2009/08/11 20:46:52 peter Exp $
- * Generated     : Tue Aug 11 22:44:39 2009
+ * Version       : $Id: dbipv6addr_assignment.h,v 1.28 2011/02/27 11:59:14 peter Exp $
+ * Generated     : Sun Feb 27 12:56:57 2011
  * Data copyright: IANA ARIN RIPENCC APNIC LACNIC AFRINIC
  *
  * Information:
@@ -28,6 +28,7 @@ static const s_ipv6addr_assignment dbipv6addr_assignment[] = {
 	{ 0x20012000, 0x00000000, 0xfffff000, 0x00000000,  20, "RIPENCC" },
 	{ 0x20013000, 0x00000000, 0xfffff800, 0x00000000,  21, "RIPENCC" },
 	{ 0x20013800, 0x00000000, 0xfffffc00, 0x00000000,  22, "RIPENCC" },
+	{ 0x20013c00, 0x00000000, 0xfffffc00, 0x00000000,  22, "IANA" },
 	{ 0x20014000, 0x00000000, 0xfffffe00, 0x00000000,  23, "RIPENCC" },
 	{ 0x20014200, 0x00000000, 0xfffffe00, 0x00000000,  23, "AFRINIC" },
 	{ 0x20014400, 0x00000000, 0xfffffe00, 0x00000000,  23, "APNIC" },
@@ -68,4 +69,7 @@ static const s_ipv6addr_assignment dbipv6addr_assignment[] = {
 	{ 0x28000000, 0x00000000, 0xfff00000, 0x00000000,  12, "LACNIC" },
 	{ 0x2a000000, 0x00000000, 0xfff00000, 0x00000000,  12, "RIPENCC" },
 	{ 0x2c000000, 0x00000000, 0xfff00000, 0x00000000,  12, "AFRINIC" },
+	{ 0x2d000000, 0x00000000, 0xff000000, 0x00000000,   8, "IANA" },
+	{ 0x2e000000, 0x00000000, 0xfe000000, 0x00000000,   7, "IANA" },
+	{ 0x30000000, 0x00000000, 0xf0000000, 0x00000000,   4, "IANA" },
 };
