@@ -1,6 +1,11 @@
 #!/bin/sh
-
-# $Id: test_showinfo.sh,v 1.7 2007/06/02 11:58:54 peter Exp $
+#
+# Project    : ipv6calc
+# File       : test_showinfo.sh
+# Version    : $Id: test_showinfo.sh,v 1.10 2007/08/11 12:04:58 peter Exp $
+# Copyright  : 2002-2007 by Peter Bieringer <pb (at) bieringer.de>
+#
+# Test patterns for ipv6calc showinfo
 
 
 getexamples() {
@@ -23,6 +28,9 @@ fe80::fefc:acff:fe10:fe01		# link-local autoconf on ISDN interface
 2001:7b0:ffff::1			# Productive IPv6
 3ffe:831f:ce49:7601:8000:efff:af4a:86BF	# Teredo
 2001:a60:f011::1			# Productive IPv6
+2001:0010:392e:a450:2cd3:75e1:6098:8104	# Orchid
+fe80::8000:5445:5245:444F		# Link-local teredo
+fe80::ffff:ffff:fffd			# Link-local teredo
 END
 }
 
