@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6calc.c
- * Version    : $Id: libipv6calc.c,v 1.17 2007/01/31 16:21:47 peter Exp $
- * Copyright  : 2001-2003 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: libipv6calc.c,v 1.18 2011/02/27 11:40:02 peter Exp $
+ * Copyright  : 2001-2011 by Peter Bieringer <pb (at) bieringer.de>
  *
  * Information:
  *  Function library for some tools
@@ -140,9 +140,9 @@ void string_to_reverse_dotted(char *string) {
  */
 #define DEBUG_function_name "libipv6calc/autodetectinput"
 uint32_t libipv6calc_autodetectinput(const char *string) {
-	uint32_t type = FORMAT_undefined;
+	uint32_t type = FORMAT_auto_noresult;
 	int i, j, result;
-	int numdots = 0, numcolons = 0, numdigits = 0, numxdigits = 0, numdashes = 0, numspaces = 0;
+	int numdots = 0, numcolons = 0, numdigits = 0, numxdigits = 0, numdashes = 0, numspaces = 0, numslashes = 0, numalnums = 0;
 	char resultstring[NI_MAXHOST];
 	size_t length;
 
@@ -157,9 +157,11 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 		if (string[i] == '.') { numdots++; };
 		if (string[i] == ':') { numcolons++; };
 		if (string[i] == '-') { numdashes++; };
+		if (string[i] == '/') { numslashes++; };
 		if (string[i] == ' ') { numspaces++; };
 		if (isdigit((int) string[i])) { numdigits++; };
 		if (isxdigit((int) string[i])) { numxdigits++; };
+		if (isalnum((int) string[i])) { numalnums++; };
 	};
 
 	if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
@@ -168,22 +170,29 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 		fprintf(stderr, "%s:  numcolons :%d\n", DEBUG_function_name, numcolons);
 		fprintf(stderr, "%s:  numdashes :%d\n", DEBUG_function_name, numdashes);
 		fprintf(stderr, "%s:  numspaces :%d\n", DEBUG_function_name, numspaces);
+		fprintf(stderr, "%s:  numslashes:%d\n", DEBUG_function_name, numslashes);
 		fprintf(stderr, "%s:  numdigits :%d\n", DEBUG_function_name, numdigits);
 		fprintf(stderr, "%s:  numxdigits:%d\n", DEBUG_function_name, numxdigits);
+		fprintf(stderr, "%s:  numalnums :%d\n", DEBUG_function_name, numalnums);
 		fprintf(stderr, "%s:  length    :%d\n", DEBUG_function_name, (int) length);
 	};
 
 	if ( length == 20 && numdots == 0 && numcolons == 0 ) {
 	        /* probably a base85 one */
+		if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_base85\n", DEBUG_function_name);
+		};
 		result = librfc1924_formatcheck(string, resultstring);	
 	        if ( result == 0 ) {
 			/* ok: base85 */
 			type = FORMAT_base85;
 			goto END_libipv6calc_autodetectinput;
+		} else if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_base85 not successful, result: %s\n", DEBUG_function_name, resultstring);
 		};
 	};
 	
-	if (length >= 7 && length <= 15 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 4 && numdigits <= 12) {
+	if (length >= 7 && length <= 15 && numdots == 3 && numcolons == 0 && numdigits == numxdigits && numdigits >= 4 && numdigits <= 12 && numslashes <= 1 && (numdots + numdigits + numslashes) == length) {
 		/* IPv4: ddd.ddd.ddd.ddd */
 		type = FORMAT_ipv4addr;
 		goto END_libipv6calc_autodetectinput;
@@ -191,11 +200,16 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 
 	if ( strncmp(string, "\\[", 2) == 0 ) {
 		/* check for Bitstring label: \[x..../dd] */
+		if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_bitstring\n", DEBUG_function_name);
+		};
 		result = librfc2874_formatcheck(string, resultstring);	
 	        if ( result == 0 ) {
 			/* ok: bitstring label */
 			type = FORMAT_bitstring;
 			goto END_libipv6calc_autodetectinput;
+		} else if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_bitstring not successful, result: %s\n", DEBUG_function_name, resultstring);
 		};
 	};
 	
@@ -215,6 +229,9 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 		/* MAC 00:00:00:00:00:00 or 00-00-00-00-00-00 or "xx xx xx xx xx xx" */
 
 		/* Check whether minimum 1 xdigit is between colons */
+		if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_mac\n", DEBUG_function_name);
+		};
 		j = 0;
 		for (i = 0; i < (int) length; i++) {
 			if (isxdigit((int) string[i])) {
@@ -248,17 +265,22 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 		};
 	};
 	
-	if (numcolons == 0 && numdots > 0) {
+	if (numcolons == 0 && numdots > 0 && numslashes == 0 && numspaces == 0 && (numalnums + numdots) == length) {
 		/* check for reverse nibble string */
+		if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_revnibbels_int\n", DEBUG_function_name);
+		};
 		result = librfc1886_formatcheck(string, resultstring);	
 	        if ( result == 0 ) {
 			/* ok: reverse nibble string */
 			type = FORMAT_revnibbles_int;
 			goto END_libipv6calc_autodetectinput;
+		} else if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
+			fprintf(stderr, "%s:  check FORMAT_revnibbels_int not successful, result: %s\n", DEBUG_function_name, resultstring);
 		};
 	};
 	
-	if (numcolons != 0 && numdots <= 3) {
+	if (numcolons != 0 && numdots <= 3 && numslashes <= 1 && (numdots + numcolons + numxdigits + numslashes) == length) {
 		/* hopefully an IPv6 address */
 		type = FORMAT_ipv6addr;
 		goto END_libipv6calc_autodetectinput;
@@ -266,7 +288,11 @@ uint32_t libipv6calc_autodetectinput(const char *string) {
 	
 END_libipv6calc_autodetectinput:	
 	if ( (ipv6calc_debug & DEBUG_libipv6calc) != 0 ) {
-		fprintf(stderr, "%s: Autodetection found type: %x\n", DEBUG_function_name, (unsigned int) type);
+		if (type != FORMAT_auto_noresult) {
+			fprintf(stderr, "%s: Autodetection found type: %x\n", DEBUG_function_name, (unsigned int) type);
+		} else {
+			fprintf(stderr, "%s: Autodetection not successful\n", DEBUG_function_name);
+		};
 	};
 	return (type);
 };
